==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkFollower.java <==
// java wrapper for vtkFollower object
//

package vtk;
import vtk.*;

public class vtkFollower extends vtkActor
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCamera_2(vtkCamera id0);
  public void SetCamera(vtkCamera id0)
    { SetCamera_2(id0); }

  private native long GetCamera_3();
  public vtkCamera GetCamera() {
    long temp = GetCamera_3();

    if (temp == 0) return null;
    return (vtkCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int RenderOpaqueGeometry_4(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_4(id0); }

  private native int RenderTranslucentPolygonalGeometry_5(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_5(id0); }

  private native void Render_6(vtkRenderer id0);
  public void Render(vtkRenderer id0)
    { Render_6(id0); }

  private native int HasTranslucentPolygonalGeometry_7();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_7(); }

  private native void ReleaseGraphicsResources_8(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_8(id0); }

  private native void ComputeMatrix_9();
  public void ComputeMatrix()
    { ComputeMatrix_9(); }

  private native void ShallowCopy_10(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_10(id0); }

  public vtkFollower() { super(); }

  public vtkFollower(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-2-armv7h.pkg.tar.xz: vtk/vtkFollower.java <==
// java wrapper for vtkFollower object
//

package vtk;
import vtk.*;

public class vtkFollower extends vtkActor
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCamera_2(vtkCamera id0);
  public void SetCamera(vtkCamera id0)
    { SetCamera_2(id0); }

  private native long GetCamera_3();
  public vtkCamera GetCamera() {
    long temp = GetCamera_3();

    if (temp == 0) return null;
    return (vtkCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int RenderOpaqueGeometry_4(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_4(id0); }

  private native int RenderTranslucentPolygonalGeometry_5(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_5(id0); }

  private native void Render_6(vtkRenderer id0);
  public void Render(vtkRenderer id0)
    { Render_6(id0); }

  private native int HasTranslucentPolygonalGeometry_7();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_7(); }

  private native void ReleaseGraphicsResources_8(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_8(id0); }

  private native void ComputeMatrix_9();
  public void ComputeMatrix()
    { ComputeMatrix_9(); }

  private native void ShallowCopy_10(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_10(id0); }

  public vtkFollower() { super(); }

  public vtkFollower(long id) { super(id); }
  public native long   VTKInit();

}
